@@ -120,7 +120,6 @@ missing = object()
 
 
 class Session(object):
-
     """A CherryPy dict-like Session object (one per request)."""
 
     _id = None
@@ -148,9 +147,11 @@ class Session(object):
     to session data."""
 
     loaded = False
+    """If True, data has been retrieved from storage.
+
+    This should happen automatically on the first attempt to access
+    session data.
     """
-    If True, data has been retrieved from storage. This should happen
-    automatically on the first attempt to access session data."""
 
     clean_thread = None
     'Class-level Monitor which calls self.clean_up.'
@@ -165,9 +166,10 @@ class Session(object):
     'True if the session requested by the client did not exist.'
 
     regenerated = False
+    """True if the application called session.regenerate().
+
+    This is not set by internal calls to regenerate the session id.
     """
-    True if the application called session.regenerate(). This is not set by
-    internal calls to regenerate the session id."""
 
     debug = False
     'If True, log debug information.'
@@ -335,8 +337,9 @@ class Session(object):
 
     def pop(self, key, default=missing):
         """Remove the specified key and return the corresponding value.
-        If key is not found, default is returned if given,
-        otherwise KeyError is raised.
+
+        If key is not found, default is returned if given, otherwise
+        KeyError is raised.
         """
         if not self.loaded:
             self.load()
@@ -351,13 +354,19 @@ class Session(object):
         return key in self._data
 
     def get(self, key, default=None):
-        """D.get(k[,d]) -> D[k] if k in D, else d.  d defaults to None."""
+        """D.get(k[,d]) -> D[k] if k in D, else d.
+
+        d defaults to None.
+        """
         if not self.loaded:
             self.load()
         return self._data.get(key, default)
 
     def update(self, d):
-        """D.update(E) -> None.  Update D from E: for k in E: D[k] = E[k]."""
+        """D.update(E) -> None.
+
+        Update D from E: for k in E: D[k] = E[k].
+        """
         if not self.loaded:
             self.load()
         self._data.update(d)
@@ -369,7 +378,10 @@ class Session(object):
         return self._data.setdefault(key, default)
 
     def clear(self):
-        """D.clear() -> None.  Remove all items from D."""
+        """D.clear() -> None.
+
+        Remove all items from D.
+        """
         if not self.loaded:
             self.load()
         self._data.clear()
@@ -492,7 +504,8 @@ class FileSession(Session):
         """Set up the storage system for file-based sessions.
 
         This should only be called once per process; this will be done
-        automatically when using sessions.init (as the built-in Tool does).
+        automatically when using sessions.init (as the built-in Tool
+        does).
         """
         # The 'storage_path' arg is required for file-based sessions.
         kwargs['storage_path'] = os.path.abspath(kwargs['storage_path'])
@@ -616,7 +629,8 @@ class MemcachedSession(Session):
         """Set up the storage system for memcached-based sessions.
 
         This should only be called once per process; this will be done
-        automatically when using sessions.init (as the built-in Tool does).
+        automatically when using sessions.init (as the built-in Tool
+        does).
         """
         for k, v in kwargs.items():
             setattr(cls, k, v)
