@@ -2,13 +2,9 @@
 
 import gzip
 import io
-try:
-    from unittest import mock
-except:
-    import mock
-
-from six.moves.http_client import IncompleteRead
-from six.moves.urllib.parse import quote as url_quote
+from unittest import mock
+from http.client import IncompleteRead
+from urllib.parse import quote as url_quote
 
 import cherrypy
 from cherrypy._cpcompat import ntob, ntou
@@ -50,7 +46,7 @@ class EncodingTests(helper.CPWebCase):
                 #  any part which is unicode (even ascii), the response
                 #  should not fail.
                 cherrypy.response.cookie['candy'] = 'bar'
-                cherrypy.response.cookie['candy']['domain'] = 'cherrypy.org'
+                cherrypy.response.cookie['candy']['domain'] = 'cherrypy.dev'
                 cherrypy.response.headers[
                     'Some-Header'] = 'My d\xc3\xb6g has fleas'
                 cherrypy.response.headers[
